@@ -1,5 +1,8 @@
 # coding: utf-8
-from __future__ import print_function
+from __future__ import unicode_literals
+
+import io
+import logging
 import os
 
 config_text = 'site_name: My Docs\n'
@@ -16,36 +19,36 @@ For full documentation visit [mkdocs.org](http://mkdocs.org).
 
 ## Project layout
 
-    mkdocs.yml    # The configuration file.
+    mkdocs.yml    # The configuration file.
     docs/
         index.md  # The documentation homepage.
         ...       # Other markdown pages, images and other files.
 """
 
+log = logging.getLogger(__name__)
 
-def new(args, options):
-    if len(args) != 1:
-        print("Usage 'mkdocs new [directory-name]'")
-        return
 
-    output_dir = args[0]
+def new(output_dir):
 
     docs_dir = os.path.join(output_dir, 'docs')
     config_path = os.path.join(output_dir, 'mkdocs.yml')
     index_path = os.path.join(docs_dir, 'index.md')
 
     if os.path.exists(config_path):
-        print('Project already exists.')
+        log.info('Project already exists.')
         return
 
     if not os.path.exists(output_dir):
-        print('Creating project directory: %s' % output_dir)
+        log.info('Creating project directory: %s', output_dir)
         os.mkdir(output_dir)
 
-    print('Writing config file: %s' % config_path)
-    open(config_path, 'w').write(config_text)
+    log.info('Writing config file: %s', config_path)
+    io.open(config_path, 'w', encoding='utf-8').write(config_text)
 
-    print('Writing initial docs: %s' % index_path)
+    if os.path.exists(index_path):
+        return
+
+    log.info('Writing initial docs: %s', index_path)
     if not os.path.exists(docs_dir):
         os.mkdir(docs_dir)
-    open(index_path, 'w').write(index_text)
+    io.open(index_path, 'w', encoding='utf-8').write(index_text)
